@@ -15,15 +15,17 @@ function(datos,q=0.50,nivel=0.95,ic=T,tipo.boot="norm",iteraciones.boot=10000,co
   	} else {
   		datos.boot<-boot(x,quantile.fun,iteraciones.boot)
   		if (!all(min.fix.na(x)==x,na.rm=T)){
-  			inter.boot<-boot.ci(datos.boot,type="all",conf=((3-colas)*nivel-2+colas))
-  			if (tipo.boot=="norm") return(c(inter.boot$normal[2],inter.boot$t0[1],inter.boot$normal[3]))
+  			inter.boot<-boot.ci(datos.boot,type=c("norm","basic","perc","stud"),conf=((3-colas)*nivel-2+colas))
+  			if (tipo.boot=="norm" || tipo.boot=="normal") return(c(inter.boot$normal[2],inter.boot$t0[1],inter.boot$normal[3]))
   			else if (tipo.boot=="basic") return(c(inter.boot$basic[4],inter.boot$t0[1],inter.boot$basic[5]))
-  			else if (tipo.boot=="stud") return(c(inter.boot$student[4],inter.boot$t0[1],inter.boot$student[5]))
-  			else if (tipo.boot=="perc") return(c(inter.boot$percent[4],inter.boot$t0[1],inter.boot$percent[5]))
-  			else if (tipo.boot=="bca") return(c(inter.boot$bca[4],inter.boot$t0[1],inter.boot$bca[5]))
-  			else return(rep(inter.boot$t0[1],3))
+  			else if (tipo.boot=="stud" || tipo.boot=="student") return(c(inter.boot$student[4],inter.boot$t0[1],inter.boot$student[5]))
+  			else if (tipo.boot=="perc" || tipo.boot=="percent") return(c(inter.boot$percent[4],inter.boot$t0[1],inter.boot$percent[5]))
+  			#else if (tipo.boot=="bca") return(c(inter.boot$bca[4],inter.boot$t0[1],inter.boot$bca[5]))
+  			#else return(rep(inter.boot$t0[1],3))
+  			else return(c(NA,inter.boot$t0[1],NA))
   		}else{
-  			return(rep(datos.boot$t0[1],3))
+  		  #return(rep(datos.boot$t0[1],3))
+  		  return(c(NA,inter.boot$t0[1],NA))
   		}
   	}
 	} else return(rep(NA,3))
